Versioning
==========

The :obj:`sdr` library uses `semantic versioning <https://semver.org/>`_. Releases are versioned `major.minor.patch`.

Major versions introduce API-changing features. Minor versions add features that are backwards-compatible with other releases.
Patch versions make backwards-compatible bug fixes.

Alpha releases
--------------

Versions before `0.1.0` are alpha releases. Alpha releases are versioned `0.0.alpha`. There is no API compatibility guarantee
for them. They can be thought of as `0.0.alpha-major`.

Beta releases
-------------

Versions before `1.0.0` are beta releases. Beta releases are versioned `0.beta.x` and are API-compatible. They can be thought
of as `0.beta-major.beta-minor`.
